capture log close
clear 
set more off

//This file labels data and declares the sources and then generates used variables and creates sum stat in table 1 and 2.

// Use your prefered location on computer
cd T:\Direct_dem_econometrica\


use data\1919_1938_long.dta, replace
tsset code8 year, yearly

//Labeling and notes declaring the sources. Following the order of table 2. Variables below are mostly presented as in the printed sources, i.e. possible to verify, in levels and nominal terms.

// Other variables
label var code8 "id variable" 
notes code8: Our id variable. Roughly following the order of Local Government Finances and Statistical Yearbook of Administrative Districts of Sweden. Statistics Sweden.
label var kommun "Name of municipality (kommun)"
notes kommun: Following the Local Government Finances. Statistics Sweden.
label var county "Name of county (ln)"
notes county: Following the Local Government Finances. Statistics Sweden.
label var direct "dummy = 1 if direct democrary, 0 for representative."
notes direct: Source: unpublished material from Statistics Sweden, kept at the Swedish National Archives 
label var kpi "consumer price index 1919-1938 in 1914 as base"
notes kpi: Source: Statistics Sweden. http://www.scb.se/Pages/TableAndChart____33895.aspx
label var cpi1917 "consumer price index 1917 in 1914 as base"
notes cpi1917: Source: Statistics Sweden. http://www.scb.se/Pages/TableAndChart____33895.aspx
label var cpi1918 "consumer price index 1918 in 1914 as base"
notes cpi1918: Source: Statistics Sweden. http://www.scb.se/Pages/TableAndChart____33895.aspx
label var elig "Nr. of eligible voters from the parliamentary elections"
notes elig: Source: Sten Berglund, Statsvetenskapliga institutionen, Ume universitet. http://snd.gu.se/sv/catalogue/study/SND0204. For source data used contact Swedish natinal data service SND. For code reading in SND-data contact authors. 
label var turnout "no. of voters in direct democracy."
notes turnout: Source: unpublished material from Statistics Sweden, kept at the Swedish National Archives 
label var many_partlist "Dummy 1 if more than one party list, 0 oterhwise"
notes many_partlist: Source: unpublished material from Statistics Sweden, kept at the Swedish National Archives. 
label var turnoutrepr "no. of voters in representative democracy."
notes turnoutrepr: Source: unpublished material from Statistics Sweden, kept at the Swedish National Archives 
label var population1917 "population, 1917"
notes population1917: Following the Local Government Finances. Statistics Sweden. 


//Panel A. Outcome variables

label var poorexpenditure "Level of social welfare spending"
notes poorexpenditure: Following the Local Government Finances. Statistics Sweden. For 1918-1927, unpublished material from Statistics Sweden, kept at the Swedish National Archives
label var poor_internal_expenditure "Level of  welfare spending,indoor"
notes poor_internal_expenditure: Following the Local Government Finances. Statistics Sweden. For 1918-1927, unpublished material from Statistics Sweden, kept at the Swedish National Archives. No information 1938
label var poor_external_expenditure "Level of  welfare spending, outdoor"
notes poor_external_expenditure: Following the Local Government Finances. Statistics Sweden. For 1918-1927, unpublished material from Statistics Sweden, kept at the Swedish National Archives. No information 1938
label var no_org_citizen "Number of organized members in unions, temperance and free churches"
notes no_org_citizen: Source: Andrae, C. G., & Lundkvist, S. (1984). http://snd.gu.se/catalogue/study/122. For source data used (association level) contact Swedish natinal data service SND. For code using SND-data contact authors. 
label var pop "Annual population as of 1st of January"
notes pop: Source: Statistical Yearbook of Administrative Districts of Sweden, and Muncipal elections. Statistics Sweden.

//Panel B. Forcing variables

label var population1918 "population, 1918"
notes population1918: Following the Local Government Finances. Statistics Sweden. 
label var lagged_1_pop "Annual population as of 1st of January 1 year lagged, based on pop"
notes lagged_1_pop: Source: Statistical Yearbook of Administrative Districts of Sweden, and Muncipal elections. Statistics Sweden.


//Panel B: Baseline or pre-treatment characteristics

//Pre-treatment outcomes 

label var poorexp1918 "Level of social welfare spending, 1918"
notes poorexp1918: Following the Local Government Finances. Statistics Sweden. For 1918-1927, unpublished material from Statistics Sweden, kept at the Swedish National Archives
label var poor_internal_exp1918 "Level of  welfare spending,indoor, 1918"
notes poor_internal_exp1918: Following the Local Government Finances. Statistics Sweden. For 1918-1927, unpublished material from Statistics Sweden, kept at the Swedish National Archives. No information 1938
label var poor_external_exp1918 "Level of  welfare spending, outdoor, 1918"
notes poor_external_exp1918: Following the Local Government Finances. Statistics Sweden. For 1918-1927, unpublished material from Statistics Sweden, kept at the Swedish National Archives
label var no_org_citizen1917 "Number of organized members in unions, temperance and free churches 1917"
notes no_org_citizen1917: Source: Andrae, C. G., & Lundkvist, S. (1984). http://snd.gu.se/catalogue/study/122. For source data used (association level) contact Swedish natinal data service SND. For code using SND-data contact authors. 

// Baseline     
label var nr_poor_relief1917 "No. of total recipients, 1917"
notes nr_poor_relief1917: Following the Local Government Finances. Statistics Sweden. 
label var nr_old_on_poor_relief1917 "No. of adults recipients, 1917"
notes nr_old_on_poor_relief1917: Following the Local Government Finances. Statistics Sweden. 
label var nr_dir_child_poor_r1917 "No. of children directly supported, 1917"
notes nr_dir_child_poor_r1917: Following the Local Government Finances. Statistics Sweden. 
label var nr_child_on_poor_r1917 "No. of children indirectly supported, 1917"
notes nr_child_on_poor_r1917: Following the Local Government Finances. Statistics Sweden. 
label var nr_fullpoor_1917 "No. of people receiving full support, 1917"
notes nr_fullpoor_1917: Following the Local Government Finances. Statistics Sweden. 
label var nr_poor_external1917 "No. of people boarded out, 1917"
notes nr_poor_external1917: Following the Local Government Finances. Statistics Sweden. 
label var nr_poor_internal1917 "No. of people in public institutions, 1917"
notes nr_poor_internal1917: Following the Local Government Finances. Statistics Sweden. 
label var poorhouse1917 "No. of public institutions, 1917"
notes poorhouse1917: Following the Local Government Finances. Statistics Sweden. 
label var poorslots1917 "No. of slots public institutions, 1917"
notes poorslots1917: Following the Local Government Finances. Statistics Sweden. 
label var area1918 "total area, 1918 in hectare"
notes area1918: Source: Statistical Yearbook of Administrative Districts of Sweden, Statistics Sweden.
label var land_area1918 "total land area, 1918 in hectare"
notes land_area1918: Source: Statistical Yearbook of Administrative Districts of Sweden, Statistics Sweden.
label var arable_land1918 "Arable land 1918 in hectare"
notes arable_land1918: Source: Statistical Yearbook of Administrative Districts of Sweden, Statistics Sweden.
label var taxbase1918 "Tax base from income, 1918"
notes taxbase1918: Source: Statistical Yearbook of Administrative Districts of Sweden, Statistics Sweden 
label var shareagri1917 "Tax base from income, 1918"
notes shareagri1917 : Source: Statistical Yearbook of Administrative Districts of Sweden, Statistics Sweden 
label var elig_state1917 "Nr. of eligible voters from the parliamentary elections in 1917"
notes elig_state1917: Source: Sten Berglund, Statsvetenskapliga institutionen, Ume universitet. http://snd.gu.se/sv/catalogue/study/SND0204. For source data used contact Swedish natinal data service SND. For code reading in SND-data contact authors. 
label var turnout_state1917 "Nr. of votes from the parliamentary elections"
notes turnout_state1917: Source: Sten Berglund, Statsvetenskapliga institutionen, Ume universitet. http://snd.gu.se/sv/catalogue/study/SND0204. For source data used contact Swedish natinal data service SND. For code reading in SND-data contact authors. 
label var leftvote1917 "Nr. of left wing voters from the parliamentary elections in 1917"
notes leftvote1917: Source: Sten Berglund, Statsvetenskapliga institutionen, Ume universitet. http://snd.gu.se/sv/catalogue/study/SND0204. For source data used contact Swedish natinal data service SND. For code reading in SND-data contact authors. 

//Generating the variables in the paper

//  Since we use logs as outcome in regression we also generate x+1 in order to take log of zero + 1
gen poorexpenditure_plus 	= 	poorexpenditure+1
gen poor_internal_exp_plus 	=	poor_internal_expenditure+1
gen poor_external_exp_plus 	= 	poor_external_expenditure+1

// pretreatment/baseline outcome
gen poorexp_plus1918		= poorexp1918+1
gen poor_internal_plus1918 = poor_internal_exp1918 + 1
gen poor_external_plus1918 = poor_external_exp1918 + 1

// Real values of the outcomes, dividing by consumer price index, denoted kpi for the repeated cross section and cpi for the baseline years with 1914 as base year. 
gen realpoor = poorexpenditure/kpi
gen realpoor_plus = poorexpenditure_plus/kpi
gen realpoor_int = poor_internal_expenditure/kpi
gen realpoor_int_plus = poor_internal_exp_plus/kpi
gen realpoor_ext = poor_external_expenditure/kpi
gen realpoor_ext_plus = poor_external_exp_plus/kpi

// Real values of pretreatment/baseline outcome
gen realtaxbase1918=  taxbase1918/ cpi1918
gen realpoorexp1918 = poorexp1918/cpi1918
gen realpoor_internal1918 = poor_internal_exp1918/cpi1918
gen realpoor_external1918 = poor_external_exp1918/cpi1918
gen realpoorexp_plus1918 = poorexp_plus1918/cpi1918
gen realpoor_internal_plus1918 = poor_internal_plus1918/cpi1918
gen realpoor_external1_plus1918 = poor_external_plus1918/cpi1918


//Dropping redundant variables
drop poorexpenditure poorexpenditure_plus poor_internal_expenditure poor_internal_exp_plus poor_external_expenditure poor_external_exp_plus ///
taxbase1918 poorexp1918 poorexp_plus1918

// Generate per capita values outcomes or share

gen percap_poor = realpoor/pop
gen percap_poor_plus = realpoor_plus/pop
gen percap_poor_internal = realpoor_int/pop
gen percap_poor_internal_plus = realpoor_int_plus/pop
gen percap_poor_external = realpoor_ext/pop
gen percap_poor_external_plus = realpoor_ext_plus/pop
gen no_org_citizen_share = no_org_citizen/pop
gen shareturnout = turnoutrepr/elig

//And for pretreatment/baseline outcome
gen percap_poor1918 = realpoorexp1918/population1918
gen percap_poor_plus1918 = realpoorexp_plus1918/population1918
gen percap_poor_internal1918 = realpoor_internal1918/population1918
gen percap_poor_internal_plus1918 = realpoor_internal_plus1918/population1918
gen percap_poor_external1918 = realpoor_external1918/population1918
gen percap_poor_external_plus1918 = realpoor_external1_plus1918/population1918
gen  no_org_citizen1917_share =  no_org_citizen1917/population1917


// generate the logs for outcomes
gen logcap_poor = ln(percap_poor_plus)
gen logcap_poor_internal = ln(percap_poor_internal_plus)
gen logcap_poor_external = ln(percap_poor_external_plus)
gen logrealpoor = ln(realpoor_plus)

// generate the logs for  pretreatment/baseline outcome
gen logcap_poor1918 = ln(percap_poor_plus1918)
gen logcap_poor_internal1918 = ln(percap_poor_internal_plus1918)
gen logcap_poor_external1918 = ln(percap_poor_external_plus1918)


//This produces normalized population 
gen zeropop = lagged_1_pop-1500
gen zeropop1919 =  population1918-1500 

//Generating instruments (Z) for t-1 and 1918
gen min_1d = 1 if zeropop<=0 & zeropop!=.
replace min_1d=0 if zeropop>0 & zeropop!=.

generate d1919 = 1 if zeropop1919 <=0 & zeropop1919!=.
replace d1919 =0 if zeropop1919>0 & zeropop1919!=.

//Interaction of control function
gen zeropopsmall = zeropop*min_1d
gen zeropop1919small = zeropop1919*d1919

//make controlfunctions up to
forvalues j= 2(1)3{
gen zeropop`j'= zeropop^`j'
gen zeropop1919`j'= zeropop1919^`j'
gen zeropopsmall`j'= zeropopsmall^`j'
gen zeropop1919small`j'= zeropop1919small^`j'
}




//generate year dummies 
quietly tab  year, gen(dum)


// Table 1 first three columns,

reg direct direct if year==1919 & zeropop>0 & direct==0
outreg2 direct  using tables\1\nr1919.rtf,  nocons  nor2   drop(direct)  nonotes ctitle("Mandatory") replace
reg direct direct if year==1919 & zeropop<=0 & direct==0
outreg2 direct  using  tables\1\nr1919.rtf,  nocons  nor2   drop(direct) nonotes  ctitle("Voluntary") append 
reg direct direct if year==1919 & zeropop<=0 & direct==1
outreg2 direct  using  tables\1\nr1919.rtf,  nocons  nor2   drop(direct)  nonotes ctitle("Direct Democracy") append 

reg direct direct if year==1923 & zeropop>0 & direct==0
outreg2 direct  using tables\1\nr1922.rtf,  nocons  nor2   drop(direct)  nonotes ctitle("Mandatory") replace
reg direct direct if year==1923 & zeropop<=0 & direct==0
outreg2 direct  using  tables\1\nr1922.rtf,  nocons  nor2   drop(direct) nonotes  ctitle("Voluntary") append 
reg direct direct if year==1923 & zeropop<=0 & direct==1
outreg2 direct  using  tables\1\nr1922.rtf,  nocons  nor2   drop(direct)  nonotes ctitle("Direct Democracy") append 

reg direct direct if year==1927 & zeropop>0 & direct==0
outreg2 direct  using tables\1\nr1926.rtf,  nocons  nor2   drop(direct)  nonotes ctitle("Mandatory") replace
reg direct direct if year==1927 & zeropop<=0 & direct==0
outreg2 direct  using  tables\1\nr1926.rtf,  nocons  nor2   drop(direct) nonotes  ctitle("Voluntary") append 
reg direct direct if year==1927 & zeropop<=0 & direct==1
outreg2 direct  using  tables\1\nr1926.rtf,  nocons  nor2   drop(direct)  nonotes ctitle("Direct Democracy") append 

reg direct direct if year==1931 & zeropop>0 & direct==0
outreg2 direct  using tables\1\nr1930.rtf,  nocons  nor2   drop(direct)  nonotes ctitle("Mandatory") replace
reg direct direct if year==1931 & zeropop<=0 & direct==0
outreg2 direct  using  tables\1\nr1930.rtf,  nocons  nor2   drop(direct) nonotes  ctitle("Voluntary") append 
reg direct direct if year==1931 & zeropop<=0 & direct==1
outreg2 direct  using  tables\1\nr1930.rtf,  nocons  nor2   drop(direct)  nonotes ctitle("Direct Democracy") append 

reg direct direct if year==1935 & zeropop>0 & direct==0
outreg2 direct  using tables\1\nr1934.rtf,  nocons  nor2   drop(direct)  nonotes ctitle("Mandatory") replace
reg direct direct if year==1935 & zeropop<=0 & direct==0
outreg2 direct  using  tables\1\nr1934.rtf,  nocons  nor2   drop(direct) nonotes  ctitle("Voluntary") append 
reg direct direct if year==1935 & zeropop<=0 & direct==1
outreg2 direct  using  tables\1\nr1934.rtf,  nocons  nor2   drop(direct)  nonotes ctitle("Direct Democracy") append 


// Table 2, summary stat

logout, save(tables\2\summarystat_A) word replace: tabstat percap_poor percap_poor_internal percap_poor_external  no_org_citizen_share    , stat( mean sd min max count) columns(statistics)
logout, save(tables\2\summarystat_B) word replace: tabstat  lagged_1_pop , stat( mean sd min max count) columns(statistics)
logout, save(tables\2\summarystat_B_C) word replace: tabstat  population1918 percap_poor1918 percap_poor_internal1918 percap_poor_external1918 no_org_citizen1917_share nr_poor_relief1917 nr_old_on_poor_relief1917 ///
nr_dir_child_poor_r1917  nr_child_on_poor_r1917  nr_fullpoor_1917  nr_poor_external1917 nr_poor_internal1917  poorhouse1917 ///
poorslots1917  area1918 land_area1918 arable_land1918    realtaxbase1918  shareagri1917  elig_state1917  turnout_state1917 ///
leftvote1917   if year==1919, stat(mean sd min max count) columns(statistics)

// Generating a variable if missing on baseline or main outcome. The units with missing on the baseline are units that typically did not excist in 1917 or 1918.
// I.e. new municipalites, typically borroughs. They are typically very large in size, i.e. far from population threshold.

gen miss1 = 1 if population1918 ==. | percap_poor_external1918==. |  percap_poor_internal1918 ==. |  nr_poor_relief1917 ==. | nr_old_on_poor_relief1917==. | ///
nr_dir_child_poor_r1917==. |  nr_child_on_poor_r1917==. |  nr_fullpoor_1917==. |  nr_poor_external1917==. | nr_poor_internal1917==. |  poorhouse1917==. | ///
poorslots1917==. |  area1918==. | land_area1918==. | arable_land1918==. |    realtaxbase1918==. |  shareagri1917==. | population1918==. |  elig_state1917==. |  turnout_state1917==. | ///
leftvote1917==. |  no_org_citizen1917_share ==. | logcap_poor==.

rename direct Direct_democracy 
compress

// First saving the dataset with no restrictions
save data\Direct_democracy_1919-1938_all, replace

drop if miss1==1
// Second saving the used data in the paper, i.e. giving constant sample over specifications. Note the results are insensitive to (no baseline controls) using the previous data set,
save data\Direct_democracy_1919-1938,replace


