capture log close
clear 
set more off
set mem 110000m
set matsize 11000

// Use your prefered location
cd T:\Direct_dem_econometrica\

use data\Direct_democracy_1919-1938, replace

// This dofile generates all the graphs presented in the paper for the forcing variable 1918

// Local for baseline controls for t-1
local d    logcap_poor1918 logcap_poor_external1918 logcap_poor_internal1918 no_org_citizen1917_share  nr_poor_relief1917 nr_old_on_poor_relief1917  ///
nr_dir_child_poor_r1917  nr_child_on_poor_r1917  nr_fullpoor_1917  nr_poor_external1917 nr_poor_internal1917  poorhouse1917 ///
poorslots1917  area1918 land_area1918 arable_land1918  realtaxbase1918 shareagri1917 population1918  elig_state1917  turnout_state1917 ///
leftvote1917   


// Some labelling for the titles of the grapps
label variable logcap_poor1918 "Log(Per cap. welfare spending)"
label variable logcap_poor_external1918 "Log(Outdoor per cap. welfare spending)"
label variable logcap_poor_internal1918 "Log(Indoor per cap. welfare spending)"
label variable nr_poor_relief1917 "No. of total recipients (incl. children)"
label variable nr_old_on_poor_relief1917 "No. of total recipients (adults)"
label variable nr_dir_child_poor_r1917 "No. of children directly supported"
 
label variable nr_child_on_poor_r1917 "No. of children indirectly supported"
label variable nr_fullpoor_1917 "No. of people receiving full support"
label variable nr_poor_external1917 "No. of people boarded out"
label variable nr_poor_internal1917 "No. of people in public institutions"
label variable poorhouse1917 "No. of public institutions"
label variable poorslots1917 "No. of slots in public institutions" 

label variable  area1918 "Total area (hectare)"
label variable land_area1918 "Land area (hectare)"
label variable arable_land1918 "Arable land (hectare)"
label variable realtaxbase1918 "People in public institutions"
label variable shareagri1917 "Income tax base"
label variable population1918 "Population 1918" 

label variable elig_state1917 "Eligible voters (parliamentary election)"
label variable turnout_state1917 "No. of voters (parliamentary election)"
label variable leftvote1917 "Share left-wing voters (parliamentary election)"
label variable no_org_citizen1917_share "Share of organized citizens" 

//This constructs a grouping variable on the distance from 0, First specify how small the bin and the width (paper has 300 as width and the size of the bin is 20)

local bin 20
local width  300

//choose the running variable zeropop or zeropop1919 and change drop if t-1 is going to be used
local z zeropop1919
local t "1918"

drop if year>1925

gen zeropopinverse = -`z' if `z' <=0
egen cat1 = cut(zeropopinverse) if `z' <=0, at(0(`bin' )`width') label
egen cat2 = cut(`z' )       if `z' >0, at(0(`bin' )`width') label
gen cat3 = (cat1*`bin' ) + (`bin' /2) 
gen cat4=  (cat2*`bin' ) + (`bin' /2) 
replace cat3 = (`width' - `bin') + (`bin' /2) if cat1 ==. & `z'  >=-`width' & `z' <=0
replace cat4 = (`width' - `bin') + (`bin' /2) if cat2 ==. & `z'  <=`width' & `z' >0
replace cat3 = -cat3
gen normpop = cat3
replace normpop = cat4 if cat3==.


// the residuals to be plotted
reg logcap_poor  dum** `d'  
predict logcap_poor_residual,resid


foreach var of varlist logcap_poor_residual Direct_democracy `d' {
              
lpoly  `var' `z'   if `z' <=0  & `z' >=-`width', kernel(rec)  bwidth(60) degree(1) n(50)   nograph gen(x y)

lpoly  `var' `z'   if `z' >0  & `z' <=`width', kernel(rec)  bwidth(60 ) degree(1) n(50)   nograph gen(z v)

bysort cat3 : egen `var'1 = mean( `var' ) if  cat3!=. & `var'!=. 
bysort cat4 : egen `var'2 = mean(`var') if cat4!=. & `var'!=. 
gen `var'3 = `var'1 if `var'!=. 
replace `var'3 = `var'2 if `z'>0  & `var'!=. 
sort x


graph twoway (scatter `var'3 normpop if `z'  <=`width' & `z' >=-`width', ms(o) mc(gs0) msize(small)) ///
(line y x if x<=-0 , lcolor(black)) (line v  z if z >=0 , lcolor(black))   /// 
, xscale(range(-`width' `width')) xlabel(#6)  ylabel(#6)    xline(0, lcolor(black))  xtitle(" " "Normalized population, `t'" ) ylabel(,angle(360)) ///
legend(off)  ytitle("") title("`: variable label `var''", color(black) size(medium)) yla(,glcolor(gs15))   ///
graphregion(fcolor(gs15))  
graph save graphs\1918\graph`var', replace
drop x y z v
}

 
// combine the baseline graphs for appendix. Note in order to excute this combining graphs instead of viewing them seperatly one needs to set the directory
// to in our case cd T:\Direct_dem_econometrica\1918\. This are the graphs combined in appendix A62
//cd T:\Direct_dem_econometrica\graphs\1918\

//gr combine "graphlogcap_poor1918" "graphlogcap_poor_internal1918" "graphlogcap_poor_external1918" "graphnr_poor_relief1917" ///
//"graphnr_old_on_poor_relief1917" "graphnr_dir_child_poor_r1917", col(2) imargin(small) iscale(.55) ysize(10) xsize(8) saving(A62_1, replace)
//gr combine "graphnr_child_on_poor_r1917" "graphnr_fullpoor_1917" "graphnr_poor_external1917" "graphnr_poor_internal1917" ///
//"graphpoorhouse1917" "graphpoorslots1917", col(2) imargin(small) iscale(.55) ysize(10) xsize(8) saving(A62_2, replace)
//gr combine "grapharea1918" "graphland_area1918" "grapharable_land1918" "graphrealtaxbase1918" "graphshareagri1917" "graphpopulation1918", ///
//col(2) imargin(small) iscale(.55) ysize(10) xsize(8) saving(A62_3, replace)
//gr combine "graphelig_state1917" "graphturnout_state1917" "graphleftvote1917" "graphno_org_citizen1917_share" ///
//, col(2) imargin(small) iscale(.55) ysize(6.667) xsize(8) saving(A62_4, replace)
 
//cd T:\Direct_dem_econometrica\


drop if year!=1919
// figure 6, McCrary, note treatment defined 1 being when pop>z

gen pop2 =`z'+1500

DCdensity pop2, breakpoint(1501) generate(Xj Yj r0 fhat se_fhat ) nograph 
gen hi = fhat + 1.96*se_fhat
gen lo = fhat  - 1.96*se_fhat

local theta2: display %5.3f r(theta)
local tse: display %5.3f r(se)
gr twoway (scatter    Yj  Xj if Xj<2000 & Xj>1000  , ms(o) mc(gs0) msize(small)) ///
(line fhat  r0 if r0>1000    & r0 < 1501) ///
(line fhat  r0 if r0<2000 & r0 >= 1501) ///
(line hi r0 if r0>1000     & r0 < 1501, lcolor(black) lwidth(vthin)) ///            
(line lo r0 if r0>1000    & r0 < 1501, lcolor(black) lwidth(vthin))    ///                  
(line hi r0 if r0<2000 & r0 >= 1501, lcolor(black) lwidth(vthin))      ///      
(line lo r0 if r0<2000 & r0 >= 1501, lcolor(black) lwidth(vthin)),        ///             
xline(1501, lcolor(black)) legend(off) xtitle("Population 1918") ylabel(,angle(360)) saving(graphs\1918\McCrary_1918, replace)




// The Raw plot as in the appendix A72

clear
cd T:\Direct_dem_econometrica\

use data\Direct_democracy_1919-1938, replace
tsset code8 year, yearly
local bin 20
local width   1500
// Note we have no variation over time in the forcing varaible
drop if year!=1919

local z zeropop1919

gen zeropopinverse = -`z' if `z' <=0
egen cat1 = cut(zeropopinverse) if `z' <=0, at(0(`bin' )`width') label
egen cat2 = cut(`z' )       if `z' >0, at(0(`bin' )`width') label
gen cat3 = (cat1*`bin' ) + (`bin' /2) 
gen cat4=  (cat2*`bin' ) + (`bin' /2) 
replace cat3 = (`width' - `bin') + (`bin' /2) if cat1 ==. & `z'  >=-`width' & `z' <=0
replace cat4 = (`width' - `bin') + (`bin' /2) if cat2 ==. & `z'  <=`width' & `z' >0
replace cat3 = -cat3
gen normpop = cat3
replace normpop = cat4 if cat3==.

sort normpop
by normpop: egen nr= count(code8) if zeropop!=. & normpop!=.

gen popsize = normpop +1500
graph twoway (scatter nr  popsize if popsize<=1500 , ms(o) mc(gs0) msize(small)) ///
(scatter nr  popsize if popsize>1500 , ms(o) mc(gs0) msize(small))  ///
, xscale(range(500 1000)) xlabel(#6)  ylabel(#6) xline(1500, lwidth(vvthin)) ytitle("Bin size") xtitle("Population 1918") ///
legend(cols(1) label(1 "Average of nr ") label(2 "Predicted line") label(3 "Predicted line")off) saving(graphs\1918\raw_1918, replace) 
